pm4py.algo.filtering.log.attr\_value\_repetition package
========================================================

Submodules
----------

pm4py.algo.filtering.log.attr\_value\_repetition.filter module
--------------------------------------------------------------

.. automodule:: pm4py.algo.filtering.log.attr_value_repetition.filter
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.filtering.log.attr_value_repetition
   :members:
   :undoc-members:
   :show-inheritance:
